@@ -1,5 +1,4 @@
 from .checkpoint import Checkpoint
 from .utils import disable_batch_norm, predict_n, batch_predict_n, measures
-from .model import Model, Mode, ModelType
-from .mc_dropout import McDropout
-# from .moment_propagation import MomentPropagation
\ No newline at end of file
+from .model import Model
+from .mc_dropout import McDropout
\ No newline at end of file
